@@ -12,3 +12,10 @@ test_that("Sequences correctly", {
   expect_equal(fct_expand_seq(x, 1),
                ordered(letters[1:15], levels = letters))
 })
+
+test_that("fct_expand_seq() fails", {
+  expect_error(fct_expand_seq("a"))
+  expect_error(fct_expand_seq(as.ordered("a"), by = NA))
+  expect_error(fct_expand_seq(as.ordered("a"), min_lvl = NA))
+  expect_error(fct_expand_seq(as.ordered("a"), max_lvl = NA))
+})
